
unit uDatas;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  DXDraws, ExtCtrls, cmpBarControl, cmpPianoRoll, cmpTrackOutputs,
  cmpMidiPlayer, cmpMidiData, HidControllerClass, ComCtrls, StdCtrls,
  DXSprite;

type  
  TDatas = class(TForm)
    ImgSkin: TImage;
    ImgStoreAnimation: TDXImageList;
    UsbHids: TJvHidDeviceController;
    MidiData: TMidiData;
    PianoRoll: TPianoRoll;
    MidiPlayer: TMidiPlayer;
    TrackOutputs: TTrackOutputs;
    Label1: TLabel;
    edtDevOnePN: TEdit;
    Label2: TLabel;
    edtDevOnePid: TEdit;
    Label3: TLabel;
    edtDevOneVid: TEdit;
    Label4: TLabel;
    edtDevTwoPid: TEdit;
    edtDevTwoVid: TEdit;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    tbTempo: TTrackBar;
    midiFile: TLabel;
    edtMidiName: TEdit;
    ImgStoreBalls: TDXImageList;
    ImgStoreContext: TDXImageList;
    ImgStoreEffect: TDXImageList;
    ImgStoreFixed: TDXImageList;
    ImgStoreGesture: TDXImageList;
    SpriteEngineLayerTwo: TDXSpriteEngine;
    SpriteEngineLayerThree: TDXSpriteEngine;
    SpriteEngineLayerFour: TDXSpriteEngine;
    ImgViewport: TImage;
    Timer1: TTimer;
    SpriteEngineLayerFive: TDXSpriteEngine;
    SpriteEngineLayerSix: TDXSpriteEngine;
    SpriteEngineLayerSeven: TDXSpriteEngine;
    Memo1: TMemo;
    procedure UsbHidsDeviceChange(Sender: TObject);
    function UsbHidsEnumerate(HidDev: TJvHidDevice; Idx: Integer): Boolean;
    procedure FormCreate(Sender: TObject);
    procedure Timer1Timer(Sender: TObject);
    procedure UsbHidsDeviceUnplug(HidDev: TJvHidDevice);
  private
    { Private declarations }
    procedure LoadImgLibrary;
    procedure LoadMidi;
  public
    { Public declarations }
  end;

var
  Datas: TDatas;

implementation

uses uScreen, uConst, uGlobal, uGoods;

{$R *.DFM}

procedure TDatas.LoadImgLibrary;
begin
  try
    ImgStoreAnimation.Items.LoadFromFile(AppPath+ImgStoreAnimationFile);
  except
    raise Exception.Create(CantLoadAnimation);
  end;
  try
    ImgStoreBalls.Items.LoadFromFile(AppPath+ImgStoreBallsFile);
  except
    raise Exception.Create(CantLoadBalls);
  end;
  try
    ImgStoreContext.Items.LoadFromFile(AppPath+ImgStoreContextFile);
  except
    raise Exception.Create(CantLoadContext);
  end;
  try
    ImgStoreEffect.Items.LoadFromFile(AppPath+ImgStoreEffectFile);
  except
    raise Exception.Create(CantLoadEffect);
  end;
  try
    ImgStoreFixed.Items.LoadFromFile(AppPath+ImgStoreFixedFile);
  except
    raise Exception.Create(CantLoadFixed);
  end;
  try
    ImgStoreGesture.Items.LoadFromFile(AppPath+ImgStoreGestureFile);
  except
    raise Exception.Create(CantLoadGesture);
  end;
end;

procedure TDatas.UsbHidsDeviceChange(Sender: TObject);
begin
  UsbHids.Enumerate;
end;

function TDatas.UsbHidsEnumerate(HidDev: TJvHidDevice;
  Idx: Integer): Boolean;
var
  buf:array [0..8] of Byte;
  towrite, toread: Cardinal;
  written, read: Cardinal;
  i:Integer;
begin
  if HidDev.ProductName='Squeeze Bal' then
  begin
    DeviceOne:=HidDev;
    UsbHids.CheckOutByIndex(HidDev,Idx);
    buf[0]:=0;
    towrite:=2;
    toread:=DeviceOne.Caps.InputReportByteLength;
    HidCheck(DeviceOne.readFile(buf,toread,read));
    for i:=0 to 8 do begin buf[i]:=0; end;
    HidCheck(DeviceOne.WriteFile(buf,towrite,written));
  end;
end;

procedure TDatas.FormCreate(Sender: TObject);
begin
  LoadMidi;
  LoadImgLibrary;
  InitialLayouts(SpriteEngineLayerTwo,
                  SpriteEngineLayerThree,
                  SpriteEngineLayerFour,
                  SpriteEngineLayerFive,
                  SpriteEngineLayerSix,
                  SpriteEngineLayerSeven);
  InitialImgStores(ImgStoreBalls,ImgStoreContext,ImgStoreEffect,
                  ImgStoreFixed,ImgStoreGesture,ImgStoreAnimation);
  CreateGoodsObjects;
  GripGame:=TGripGame.Create;
  StressOne:=GripGame.StressOne;
  StressOne.HidDev:=DeviceOne;
  StressOne.EasyMode:=ScreenForm.CheckBox1.Checked;
  StressTwo:=GripGame.StressTwo;
//  StressTwo.HidDev:=DeviceTwo;
  MarkerOne:=GripGame.MarkerOne;
  PercentagOne:=GripGame.PercentagOne;
  ComboOne:=GripGame.ComboOne;
  Explode:=TExplode.Create(LayoutSeven.Engine);
  Ok:=TOk.Create(LayoutSeven.Engine); 
end;

procedure TDatas.LoadMidi;
begin
  MidiData.FileName:=AppPath+MidiFileName;
  MidiData.Active:=true;
  TrackOutputs.Active:=true;
  MidiPlayer.reset;
  PianoRoll.Reset;
  MidiPlayer.TempoPercent:=ScreenForm.TrackBar1.Position;
end;

procedure TDatas.Timer1Timer(Sender: TObject);
const
  lastbeat:Integer=0;
var
  bar,beat,tick:Integer;
  note:TNoteRec;
begin
  GripGame.NotifyDevice;
  if not MidiPlayer.Play then exit;
  MidiPlayer.GetBarPos(bar,beat,tick);
  note.bar:=bar;
  note.beat:=beat;
  note.tick:=tick;
//  if lastbeat<>beat then
//  begin
//    lastbeat:=beat;
    GripGame.NotifyNote(note);
//  end;
end;

procedure TDatas.UsbHidsDeviceUnplug(HidDev: TJvHidDevice);
begin
  if HidDev=StressOne.HidDev then
  begin
    UsbHids.CheckIn(HidDev);
    StressOne.HidDev:=nil;
  end;
end;

initialization
finalization

end.
